@samitouri / QOS-React-2 / commits / b805eff032

Upgrade populist dependency to v0.1.6.

This reduces the time taken by `grunt populist:test` from 7s to 550ms, which should make @spicyj especially happy. Relevant commits from the `populist` and `ast-types` repositories: https://github.com/benjamn/populist/commit/9863ad16c0753f714fdb83007515637511c346d6 https://github.com/benjamn/ast-types/commit/dabef2a4ac48ebdb5c76baf1fb94f4997b6484ac

Ben Newman committed Dec 17, 2013 at 16:26 UTC b805eff032e46fa4fadfd361623787e4d5272ac8
1 file changed +1 -1
package.json
+1 -1
@@ -40,7 +40,7 @@
40 "devDependencies": {
41 "browserify": "~2.36.1",
42 "envify": "~0.2.0",
43 - "populist": "~0.1.5",
43 + "populist": "~0.1.6",
44 "grunt-cli": "~0.1.9",
45 "grunt": "~0.4.1",
46 "grunt-contrib-copy": "~0.4.1",